==> dif-database-repository-2.1.9-1-20151124.173937-3-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UserGroups.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * UserGroups
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class UserGroups extends AbstractBeanAttributes implements java.io.Serializable {

    /** UserGroups attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");

            return list;
        }
    }

    /** UserGroups FK class */
    public static class FK {
        /** groups relation */
        public static final String GROUPS = "groups";
        /** users relation */
        public static final String USERS = "users";
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("groups".equalsIgnoreCase(attributeName))
            return groups;
        if ("users".equalsIgnoreCase(attributeName))
            return users;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("groups".equalsIgnoreCase(attributeName))
            groups = (Groups)attributeValue;
        if ("users".equalsIgnoreCase(attributeName))
            users = (Users)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** groups private attribute */
    private Groups groups;

    /** users private attribute */
    private Users users;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public UserGroups() {
    }


    /**
     * full constructor
	 *
     * @param groups
     * @param users
     */
    public UserGroups(Groups groups, Users users) {
        this.groups = groups;
        this.users = users;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return UserGroups modified instance
     */
    public UserGroups setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * groups getter method
     *
     * @return groups method
     */
    public Groups getGroups() {
        return this.groups;
    }
    
    /**       
     * groups setter method
     *
     * @param groups
     *
     * @return UserGroups modified instance
     */
    public UserGroups setGroups(Groups groups) {
        this.groups = groups;
        
        return this;
    }
    /**       
     * users getter method
     *
     * @return users method
     */
    public Users getUsers() {
        return this.users;
    }
    
    /**       
     * users setter method
     *
     * @param users
     *
     * @return UserGroups modified instance
     */
    public UserGroups setUsers(Users users) {
        this.users = users;
        
        return this;
    }

    /**
     * Creates a String representation of the UserGroups object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the UserGroups object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(UserGroups other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

    }


}

==> dif-database-repository-2.1.9-12-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UserGroups.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * UserGroups Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class UserGroups extends AbstractBeanAttributes implements java.io.Serializable {

    /** UserGroups attributes enumeration */
    public static class Fields {

        /** id column */
        public static final String ID = "id";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");

            return list;
        }
    }

    /** UserGroups FK class */
    public static class FK {

        /** groups relation */
        public static final String GROUPS = "groups";
        /** users relation */
        public static final String USERS = "users";
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("groups".equalsIgnoreCase(attributeName))
            return groups;
        if ("users".equalsIgnoreCase(attributeName))
            return users;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("groups".equalsIgnoreCase(attributeName))
            groups = (Groups) attributeValue;
        if ("users".equalsIgnoreCase(attributeName))
            users = (Users) attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** groups private attribute */
    private Groups groups;

    /** users private attribute */
    private Users users;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            return value.toString().trim();
        }
    }

    // Constructors

    /**
     * default constructor
     */
    public UserGroups()
    {}

    /**
     * full constructor
     *
     * @param groups
     * @param users
     */
    public UserGroups(Groups groups, Users users)
    {
        this.groups = groups;
        this.users = users;
    }

    // Property accessors

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * id setter method
     *
     * @param id
     * @return UserGroups modified instance
     */
    public UserGroups setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * groups getter method
     *
     * @return groups method
     */
    public Groups getGroups()
    {
        return this.groups;
    }

    /**
     * groups setter method
     *
     * @param groups
     * @return UserGroups modified instance
     */
    public UserGroups setGroups(Groups groups)
    {
        this.groups = groups;

        return this;
    }

    /**
     * users getter method
     *
     * @return users method
     */
    public Users getUsers()
    {
        return this.users;
    }

    /**
     * users setter method
     *
     * @param users
     * @return UserGroups modified instance
     */
    public UserGroups setUsers(Users users)
    {
        this.users = users;

        return this;
    }

    /**
     * Creates a String representation of the UserGroups object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

    /**
     * Compares the String representation of the UserGroups object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(UserGroups other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

    }

}
